<?php

namespace Routiz\Inc\Src\Admin;

use \Routiz\Inc\Src\Request\Request;
use \Routiz\Inc\Src\Wallet;

class Settings {

    use \Routiz\Inc\Src\Traits\Singleton;

    function __construct() {

        // add settings page to rz_listing
        add_action( 'admin_menu' , [ $this, 'add_submenu_page' ] );

        // update settings
        add_action( 'routiz/admin/update_settings', [ $this, 'update_settings' ] );

        // update payouts
        add_action( 'routiz/admin/update_payouts', [ $this, 'update_payouts' ] );

    }

    public function enqueue_menu_scripts() {
        Panel::instance();
    }

    public function add_submenu_page() {

        add_submenu_page(
            'edit.php?post_type=rz_listing_type', // parent slug
            esc_html__('Payouts', 'routiz'), // page title
            esc_html__('Payouts', 'routiz'), // menu title
            'manage_options', // capability
            'rz_payouts', // menu slug
            [ $this, 'payouts_page_output' ]
        );

        add_action( sprintf( 'load-%s',
            add_submenu_page(
                'edit.php?post_type=rz_listing_type', // parent slug
                esc_html__('Settings', 'routiz'), // page title
                esc_html__('Settings', 'routiz'), // menu title
                'manage_options', // capability
                'rz_settings', // menu slug
                [ $this, 'settings_page_output' ]
            )),
            [ $this, 'enqueue_menu_scripts' ]
        );

    }

    public function settings_page_output() {

        if( isset( $_POST ) and ! empty( $_POST ) ) {
            do_action('routiz/admin/update_settings');
        }

        Rz()->the_template('admin/settings/settings');

    }

    public function payouts_page_output() {

        do_action('routiz/admin/update_payouts');

        Rz()->the_template('admin/payouts/payouts');

    }

    public function update_settings() {

        if( isset( $_POST ) and ! empty( $_POST ) ) {

            foreach( $_POST as $id => $value ) {
                if( substr( $id, 0, 3 ) == 'rz_' ) {
                    update_option(
                        $id,
                        $value
                    );
                }
            }
        }
    }

    public function update_payouts() {

        if( ! current_user_can( 'manage_options' ) ) {
            return;
        }

        $request = Request::instance();

        if( $request->has('action') ) {

            $payout_id = (int) $request->get('id');

            switch( $request->get('action') ) {
                case 'approve':
                    Wallet::approve_payout( $payout_id );
                    break;
                case 'decline':
                    Wallet::decline_payout( $payout_id );
                    break;
            }
        }
    }
}
