<?php

namespace Routiz\Inc\Src\Explore\Filter\Modules\Geo;

use \Routiz\Inc\Src\Explore\Filter\Modules\Module;
use \Routiz\Inc\Src\Explore\Filter\Comparison;

class Geo extends Module {

    public $distance;
    public $measure;

    public function main_query() {

        $this->lat = floatval( $_GET['geo_lat'] );
        $this->lng = floatval( $_GET['geo_lng'] );
        $this->distance = (int) apply_filters('routiz/geolocation/distance', 5 );
        $this->measure = get_option('rz_measure_system') == 'metric' ? 1.609344 : 1;

        $listing_ids = $this->get_nearby_listing_ids();

        if( ! $listing_ids ) {
            $listing_ids = [0];
        }

        return [
            'post__in' => $listing_ids
        ];

    }

    public function get_nearby_listing_ids() {
        return $this->extract_ids( $this->get_by_lat_lng() );
    }

    public function extract_ids( $results ) {
        return wp_list_pluck( $results, 'post_id' );
    }

    public function get_by_lat_lng() {

        global $wpdb;

        $results = $wpdb->get_results("
            SELECT * FROM (
                SELECT *,
                    (
                        (
                            (
                                acos(
                                    sin(( {$this->lat} * pi() / 180))
                                    *
                                    sin(( lat * pi() / 180)) + cos(( {$this->lat} * pi() /180 ))
                                    *
                                    cos(( lat * pi() / 180)) * cos((( {$this->lng} - lng) * pi()/180)))
                            ) * 180/pi()
                        ) * 60 * 1.1515 * {$this->measure}
                    )
                as distance FROM (
                        SELECT * FROM (
                            SELECT LAT.meta_id, LAT.post_id, LAT.meta_value AS lat, LNG.meta_value AS lng FROM {$wpdb->postmeta} LNG
                            INNER JOIN {$wpdb->postmeta} LAT ON LAT.post_id = LNG.post_id
                            INNER JOIN {$wpdb->posts} POSTS ON LAT.post_id = POSTS.ID
                            WHERE LAT.meta_key = 'rz_location__lat'
                            AND LNG.meta_key = 'rz_location__lng'
                            AND POSTS.post_status = 'publish'
                        ) {$wpdb->postmeta}
                    ) as meta_locations
                ) meta_locations
            WHERE distance <= {$this->distance}
            ORDER BY distance ASC
            LIMIT 999
        ");

        $results_keyed = $post_ids = [];
        foreach( $results as $row ) {
            $results_keyed[ $row->post_id ] = $row;
            $post_ids[] = $row->post_id;
        }

        $this->results_keyed = $results_keyed;
        $this->post_ids = $post_ids;

        return $results;

    }

    public function get_distance_between_locations( $lat1, $lng1, $lat2, $lng2, $unit = 'km' ) {

        $theta = $lng1 - $lng2;
        $distance = sin( deg2rad( $lat1 ) ) * sin( deg2rad( $lat2 ) ) + cos( deg2rad( $lat1 ) ) * cos( deg2rad( $lat2 ) ) * cos( deg2rad( $theta ) );

        $distance = acos( $distance );
        $distance = rad2deg( $distance );
        $distance = $distance * 60 * 1.1515;

        switch( $unit ) {
            case 'mi': break;
            case 'km' : $distance = $distance * 1.609344;
        }

        return round( $distance, 2 );

    }

    public function query() {
        return [];
    }

    public function get() {

        $this->before_get();

        $field = $this->component->form->create( (array) $this->props );

        if( ! $field instanceof \Routiz\Inc\Src\Error ) {
            return sprintf( $this->wrapper(), $this->props->type, $field->get() );
        }

    }

}
