<?php

namespace Routiz\Inc\Src\Notification\Notifications;

class New_Booking extends \Routiz\Inc\Src\Notification\Base {

    public $user_can_manage = true;

    /*
     * general
     *
     */
    public function get_id() {
        return 'new-booking';
    }

    public function get_name() {
        return esc_html__('New reservation has been received', 'routiz');
    }

    /*
     * email
     *
     */
    public function get_email_subject() {
        return esc_html__( 'New reservation has been received', 'routiz' );
    }

    public function get_email_template() {
        return esc_html__( "Hello {name},\r\n\r\nYou have received a new reservation.", 'routiz' );
    }

    /*
     * email admin
     *
     */
    public function get_email_admin_subject() {
        return esc_html__( 'New reservation', 'routiz' );
    }

    public function get_email_admin_template() {
        return esc_html__( "Hello,\r\n\r\nA new reservation have been sent", 'routiz' );
    }

    /*
     * site
     *
     */
    public function get_site_icon() {
        return 'material-icon-date_range';
    }

    public function get_site_message() {
        return esc_html__( 'New reservation has been received', 'routiz' );
    }

    public function get_site_url() {
        return wc_get_account_endpoint_url( 'entries' );
    }

    public function after_send() {

        if( ! $this->params['listing']->id ) {
            return;
        }

        if( ! $this->params['request_user_id'] ) {
            return;
        }

        $params = array_merge([
            'guests' => 0,
            'checkin' => '',
            'checkout' => '',
        ], $this->params );

        if( $this->params['listing']->type->get('rz_enable_reservation_webhook') ) {
            if( $reservation_webhook_url = $this->params['listing']->type->get('rz_reservation_webhook') ) {

                // check for valid webhook url
                if( filter_var( $reservation_webhook_url, FILTER_VALIDATE_URL ) === FALSE ) {
                    return;
                }

                $request_user_id = $this->params['request_user_id'];
                $userdata = get_userdata( $request_user_id );

                $data = array_merge( [
                    'guests' => $params['guests'],
                    'checkin' => $params['checkin'],
                    'checkout' => $params['checkout'],
                ], [
                    'email' => $userdata->user_email,
                    'name' => $userdata->display_name,
                    'first_name' => $userdata->first_name,
                    'last_name' => $userdata->last_name,
                    'billing_first_name' => get_user_meta( $request_user_id, 'billing_first_name', true ),
                    'billing_last_name' => get_user_meta( $request_user_id, 'billing_last_name', true ),
                    'billing_email' => get_user_meta( $request_user_id, 'billing_email', true ),
                    'billing_phone' => get_user_meta( $request_user_id, 'billing_phone', true ),
                    'billing_country' => get_user_meta( $request_user_id, 'billing_country', true ),
                    'billing_city' => get_user_meta( $request_user_id, 'billing_city', true ),
                    'billing_postcode' => get_user_meta( $request_user_id, 'billing_postcode', true ),
                ]);

                $ch = curl_init( $reservation_webhook_url );
                curl_setopt( $ch, CURLOPT_HTTPHEADER, [
                    'Content-type: application/json'
                ]);
                curl_setopt( $ch, CURLOPT_POST, 1);
                curl_setopt( $ch, CURLOPT_POSTFIELDS, json_encode( $data, JSON_UNESCAPED_SLASHES | JSON_UNESCAPED_UNICODE ));
                curl_setopt( $ch, CURLOPT_FOLLOWLOCATION, 1);
                curl_setopt( $ch, CURLOPT_HEADER, 0);
                curl_setopt( $ch, CURLOPT_RETURNTRANSFER, 1);

                $response = curl_exec( $ch );

                curl_close( $ch );

            }
        }

    }

}
